==> odoo8_addon_l10n_es_aeat_mod115-8.0.1.3.0-py2-none-any.whl: odoo_addons/l10n_es_aeat_mod115/__openerp__.py <==
# -*- encoding: utf-8 -*-
##############################################################################
#
#  OpenERP, Open Source Management Solution.
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program. If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

{
    'name': 'AEAT modelo 115',
    'version': '8.0.1.3.0',
    'category': "Localisation/Accounting",
    'author': "Serv. Tecnol. Avanzados - Pedro M. Baeza,"
              "AvanzOSC,"
              "Antiun Ingeniería S.L.,"
              "Factor Libre S.L.,"
              "Odoo Community Association (OCA)",
    'website': "https://github.com/OCA/l10n-spain",
    'license': 'AGPL-3',
    'depends': ['l10n_es_aeat'],
    'data': [
        'data/aeat_export_mod115_2017_data.xml',
        'wizard/export_mod115_to_boe.xml',
        'views/mod115_view.xml',
        'security/ir.model.access.csv'],
    'installable': True,
}

==> odoo8_addon_l10n_es_aeat_mod115-8.0.1.3.0.99.dev5-py2-none-any.whl: odoo_addons/l10n_es_aeat_mod115/__openerp__.py <==
# -*- encoding: utf-8 -*-
##############################################################################
#
#  OpenERP, Open Source Management Solution.
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program. If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

{
    'name': 'AEAT modelo 115',
    'version': '8.0.1.3.0',
    'category': "Localisation/Accounting",
    'author': "Serv. Tecnol. Avanzados - Pedro M. Baeza,"
              "AvanzOSC,"
              "Antiun Ingeniería S.L.,"
              "Factor Libre S.L.,"
              "Odoo Community Association (OCA)",
    'website': "https://github.com/OCA/l10n-spain",
    'license': 'AGPL-3',
    'depends': ['l10n_es_aeat'],
    'data': [
        'data/aeat_export_mod115_2017_data.xml',
        'wizard/export_mod115_to_boe.xml',
        'views/mod115_view.xml',
        'security/ir.model.access.csv',
        'security/ir_rule.xml'],
    'installable': True,
}
